@@ -7,11 +7,11 @@
 ## http://search.cpan.org/dist/Devel-NYTProf/
 ##
 ###########################################################
-## $Id: NYTProf.pm 482 2008-10-01 15:30:43Z tim.bunce $
+## $Id: NYTProf.pm 497 2008-10-08 22:34:59Z tim.bunce $
 ###########################################################
 package Devel::NYTProf;
 
-our $VERSION = '2.04';
+our $VERSION = '2.05';
 
 package    # hide the package from the PAUSE indexer
     DB;
@@ -253,14 +253,11 @@ The profiler is fast enough that you shouldn't need to disable this feature.
 
 Set to 1 to enable use of the traditional DB::DB() subroutine to perform
 profiling, instead of the faster 'opcode redirection' technique that's used by
-default. It also disables some extra mechanisms that help ensure more accurate
-results for things like the last statements in subroutines.
+default. Also effectively sets C<leave=0> (see above).
 
 The default 'opcode redirection' technique can't profile subroutines that were
 compiled before NYTProf was loaded. So using use_db_sub=1 can be useful in
 cases where you can't load the profiler early in the life of the application.
-If this proves to be useful to you then please let us know, otherwise this
-vestige of old slower ways is likely to be removed.
 
 =head2 usecputime=1
 
@@ -289,6 +286,17 @@ rise significantly. Using level 1 still gives you a significant reduction in fil
 
 If NYTProf was not compiled with compression support, this option is silently ignored.
 
+=head2 clock=N
+
+Systems which support the C<clock_gettime()> system call typically
+support several clocks. By default NYTProf uses CLOCK_MONOTONIC.
+This option enables you to select a different clock by specifying the
+integer id of the clock (which may vary between systems). If the clock
+you select isn't available then CLOCK_REALTIME is used.
+
+This is a wizardly option and best avoided unless you really know what
+you're doing and understand the subtle differences between the clocks.
+
 =head1 SELECTIVE PROFILING
 
 You can profile only parts of an application by calling DB::enable_profile()
